/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.annotation;

import org.pepstock.charba.client.resources.AbstractInjectableResource;
import org.pepstock.charba.client.resources.ResourceName;

/**
 * Contains the content of <code>chartjs-plugin-annotation.min.js</code> to inject.<br>
 * 
 * @author Andrea "Stock" Stocchero
 *
 */
final class AnnotationPluginResource extends AbstractInjectableResource {

	// encoded javascript content of chartjs-plugin-annotation.min.js
	private static final String[] CONTENT = {
		"/*!",
		"* chartjs-plugin-annotation v1.1.0",
		"* https://www.chartjs.org/chartjs-plugin-annotation/index",
		" * (c) 2021 chartjs-plugin-annotation Contributors",
		" * Released under the MIT License",
		" */",
		"!function(e,t){\"object\"==typeof exports&&\"undefined\"!=typeof module?module.exports=t(require(\"chart.js\"),require(\"chart.js/helpers\")):\"function\"==typeof define&&define.amd?define([\"chart.js\",\"chart.js/helpers\"],t):(e=\"undefined\"!=typeof globalThis?globalThis:e||self)[\"chartjs-plugin-annotation\"]=t(e.Chart,e.Chart.helpers)}(this,(function(e,t){\"use strict\";const n=[\"click\",\"dblclick\"],o=[\"enter\",\"leave\"],i=n.concat(o);function r(e,t,n,o){if(t.listened)switch(n.type){case\"mousemove\":case\"mouseout\":!function(e,t,n){if(!t.moveListened)return;let o;\"mousemove\"===n.type&&(o=s(t.elements,n));const i=t.hovered;t.hovered=o,function(e,t,n,o){const{previous:i,element:r}=n;i&&i!==r&&a(e,i.options.leave||t.listeners.leave,i,o);r&&r!==i&&a(e,r.options.enter||t.listeners.enter,r,o)}(e,t,{previous:i,element:o},n)}(e,t,n);break;case\"click\":!function(e,t,n,o){const i=t.listeners,r=s(t.elements,n);if(r){const t=r.options,s=t.dblclick||i.dblclick,l=t.click||i.click;r.cli",
		"ckTimeout?(clearTimeout(r.clickTimeout),delete r.clickTimeout,a(e,s,r,n)):s?r.clickTimeout=setTimeout((()=>{delete r.clickTimeout,a(e,l,r,n)}),o.dblClickSpeed):a(e,l,r,n)}}(e,t,n,o)}}function a(e,n,o,i){t.callback(n,[{chart:e,element:o},i])}function s(e,n){let o=Number.POSITIVE_INFINITY;return e.filter((e=>e.options.display&&e.inRange(n.x,n.y))).reduce(((e,i)=>{const r=i.getCenterPoint(),a=t.distanceBetweenPoints(n,r);return a<o?(e=[i],o=a):a===o&&e.push(i),e}),[]).sort(((e,t)=>e._index-t._index)).slice(0,1)[0]}const l=(e,t,n)=>Math.min(n,Math.max(t,e));function d(e,t,n){for(const o of Object.keys(e))e[o]=l(e[o],t,n);return e}function c(e,n,o){return n=\"number\"==typeof n?n:e.parse(n),t.isFinite(n)?e.getPixelForValue(n):o}class h extends e.Element{inRange(e,t,n){const{x:o,y:i,width:r,height:a}=this.getProps([\"x\",\"y\",\"width\",\"height\"],n);return e>=o&&e<=o+r&&t>=i&&t<=i+a}getCenterPoint(e){const{x:t,y:n,width:o,height:i}=this.getProps([\"x\",\"y\",\"width\",\"height\"],e);return{",
		"x:t+o/2,y:n+i/2}}draw(e){const{x:n,y:o,width:i,height:r,options:a}=this;e.save(),e.lineWidth=a.borderWidth,e.strokeStyle=a.borderColor,e.fillStyle=a.backgroundColor,e.setLineDash(a.borderDash),e.lineDashOffset=a.borderDashOffset,e.beginPath(),t.addRoundedRectPath(e,{x:n,y:o,w:i,h:r,radius:d(t.toTRBLCorners(t.valueOrDefault(a.cornerRadius,a.borderRadius)),0,Math.min(i,r)/2)}),e.closePath(),e.fill(),a.borderWidth&&e.stroke(),e.restore()}resolveElementProperties(e,t){const n=e.scales[t.xScaleID],o=e.scales[t.yScaleID];let i,r,{top:a,left:s,bottom:l,right:d}=e.chartArea;return n||o?(n&&(i=c(n,t.xMin,s),r=c(n,t.xMax,d),s=Math.min(i,r),d=Math.max(i,r)),o&&(i=c(o,t.yMin,l),r=c(o,t.yMax,a),a=Math.min(i,r),l=Math.max(i,r)),{x:s,y:a,x2:d,y2:l,width:d-s,height:l-a}):{options:{}}}}h.id=\"boxAnnotation\",h.defaults={display:!0,adjustScaleRange:!0,borderDash:[],borderDashOffset:0,borderWidth:1,borderRadius:0,xScaleID:\"x\",xMin:void 0,xMax:void 0,yScaleID:\"y\",yMin:void 0,yMax:void 0},h.defaultRoute",
		"s={borderColor:\"color\",backgroundColor:\"color\"};const u=Math.PI,f=(e,t,n)=>({x:e.x+n*(t.x-e.x),y:e.y+n*(t.y-e.y)}),x=(e,t,n)=>f(t,n,Math.abs((e-t.y)/(n.y-t.y))).x,y=(e,t,n)=>f(t,n,Math.abs((e-t.x)/(n.x-t.x))).y;function b({x:e,y:t,x2:n,y2:o},{top:i,right:r,bottom:a,left:s}){return!(e<s&&n<s||e>r&&n>r||t<i&&o<i||t>a&&o>a)}function g({x:e,y:t},n,{top:o,right:i,bottom:r,left:a}){return e<a&&(t=y(a,{x:e,y:t},n),e=a),e>i&&(t=y(i,{x:e,y:t},n),e=i),t<o&&(e=x(o,{x:e,y:t},n),t=o),t>r&&(e=x(r,{x:e,y:t},n),t=r),{x:e,y:t}}class p extends e.Element{intersects(e,t,n=.001){const o=e=>e*e,{x:i,y:r,x2:a,y2:s}=this,l=a-i,d=s-r,c=o(l)+o(d),h=0===c?-1:((e-i)*l+(t-r)*d)/c;let u,f;return h<0?(u=i,f=r):h>1?(u=a,f=s):(u=i+h*l,f=r+h*d),o(e-u)+o(t-f)<n}labelIsVisible(e){const t=this.options.label;return(!e||b(this,e))&&t&&t.enabled&&t.content}isOnLabel(e,t){const{labelRect:n}=this;if(!n||!this.labelIsVisible())return!1;const{x:o,y:i}=(r={x:e,y:t},a=n,s=-n.rotation,l=Math.cos(s),d=Math.sin(s),c=a.x,h=a.y,{x:c",
		"+l*(r.x-c)-d*(r.y-h),y:h+d*(r.x-c)+l*(r.y-h)});var r,a,s,l,d,c,h;const u=n.width/2,f=n.height/2;return o>=n.x-u&&o<=n.x+u&&i>=n.y-f&&i<=n.y+f}inRange(e,t){const n=this.options.borderWidth||1;return this.intersects(e,t,n)||this.isOnLabel(e,t)}getCenterPoint(){return{x:(this.x2+this.x)/2,y:(this.y2+this.y)/2}}draw(e){const{x:t,y:n,x2:o,y2:i,options:r}=this;e.save(),e.lineWidth=r.borderWidth,e.strokeStyle=r.borderColor,e.setLineDash(r.borderDash),e.lineDashOffset=r.borderDashOffset,e.beginPath(),e.moveTo(t,n),e.lineTo(o,i),e.stroke(),e.restore()}drawLabel(e,n){this.labelIsVisible(n)&&(e.save(),function(e,n,o){const i=n.options.label,{borderWidth:r,xPadding:a,yPadding:s,content:l}=i,c=t.toFont(i.font);e.font=c.string;const{width:h,height:x}=function(e,n,o){const i=n.content,r=n.borderWidth;if(i instanceof Image)return{width:m(i.width,n.width)+2*n.xPadding+r,height:m(i.height,n.height)+2*n.yPadding+r};const a=t.isArray(i)?i:[i],s=a.length;let l=0;for(let t=0;t<s;t++){const n=a[t],i=o.string+",
		"\"-\"+n;w.has(i)||w.set(i,e.measureText(n).width),l=Math.max(l,w.get(i))}return l+=2*n.xPadding+r,{width:l,height:s*o.lineHeight+2*n.yPadding+r}}(e,i,c),y=n.labelRect=function(e,n,o,i){const r=e.options.label,{xAdjust:a,yAdjust:s,xPadding:l,yPadding:d,position:c}=r,h={x:e.x,y:e.y},x={x:e.x2,y:e.y2},y=\"auto\"===r.rotation?function(e){const{x:t,y:n,x2:o,y2:i}=e,r=Math.atan2(i-n,o-t);return r>u/2?r-u:r<u/-2?r+u:r}(e):t.toRadians(r.rotation),b=function(e,t,n){const o=Math.cos(n),i=Math.sin(n);return{w:Math.abs(e*o)+Math.abs(t*i),h:Math.abs(e*i)+Math.abs(t*o)}}(n,o,y),g=function(e,t,n,o){let i=.5;const r=function(e,t){const{x:n,x2:o,y:i,y2:r}=e,a=Math.min(i,r)-t.top,s=Math.min(n,o)-t.left,l=t.bottom-Math.max(i,r),d=t.right-Math.max(n,o);return{x:Math.min(s,d),y:Math.min(a,l),dx:s<d?1:-1,dy:a<l?1:-1}}(e,o),a=e.options.label;\"start\"===t?i=M({w:e.x2-e.x,h:e.y2-e.y},n,a,r):\"end\"===t&&(i=1-M({w:e.x-e.x2,h:e.y-e.y2},n,a,r));return i}(e,c,b,i),p=f(h,x,g),m={size:b.w,min:i.left,max:i.right,padd",
		"ing:l},w={size:b.h,min:i.top,max:i.bottom,padding:d};return{x:v(p.x,m)+a,y:v(p.y,w)+s,width:n,height:o,rotation:y}}(n,h,x,o);e.translate(y.x,y.y),e.rotate(y.rotation),e.fillStyle=i.backgroundColor;const b=function(e,t){if(t.borderWidth)return e.lineCap=t.borderCapStyle,e.setLineDash(t.borderDash),e.lineDashOffset=t.borderDashOffset,e.lineJoin=t.borderJoinStyle,e.lineWidth=t.borderWidth,e.strokeStyle=t.borderColor,!0}(e,i);e.beginPath(),t.addRoundedRectPath(e,{x:-h/2,y:-x/2,w:h,h:x,radius:d(t.toTRBLCorners(t.valueOrDefault(i.cornerRadius,i.borderRadius)),0,Math.min(h,x)/2)}),e.closePath(),e.fill(),b&&e.stroke();if(e.fillStyle=i.color,l instanceof Image){const t=-h/2+a+r/2,n=-x/2+s+r/2;e.drawImage(l,t,n,h-2*a-r,x-2*s-r)}else{const n=t.isArray(l)?l:[l],o=function(e,t){const{textAlign:n,xPadding:o,borderWidth:i}=e;if(\"start\"===n)return-t/2+o+i/2;if(\"end\"===n)return+t/2-o-i/2;return 0}(i,h),r=-(n.length-1)*c.lineHeight/2;e.textBaseline=\"middle\",e.textAlign=i.textAlign,n.forEach(((t,n)=",
		">e.fillText(t,o,r+n*c.lineHeight)))}}(e,this,n),e.restore())}resolveElementProperties(e,t){const n=e.scales[t.scaleID];let o,i,{top:r,left:a,bottom:s,right:l}=e.chartArea;if(n)o=c(n,t.value,NaN),i=c(n,t.endValue,o),n.isHorizontal()?(a=o,l=i):(r=o,s=i);else{const n=e.scales[t.xScaleID],o=e.scales[t.yScaleID];n&&(a=c(n,t.xMin,a),l=c(n,t.xMax,l)),o&&(r=c(o,t.yMin,r),s=c(o,t.yMax,s))}return b({x:a,y:r,x2:l,y2:s},e.chartArea)?function(e,t,n){const{x:o,y:i}=g(e,t,n),{x:r,y:a}=g(t,e,n);return{x:o,y:i,x2:r,y2:a,width:Math.abs(r-o),height:Math.abs(a-i)}}({x:a,y:r},{x:l,y:s},e.chartArea):{x:a,y:r,x2:l,y2:s,width:Math.abs(l-a),height:Math.abs(s-r)}}}function m(e,t){return\"number\"==typeof t?t:\"string\"==typeof t?(\"string\"==typeof(n=t)&&n.endsWith(\"%\")&&parseFloat(n)/100)*e:e;var n}p.id=\"lineAnnotation\",p.defaults={display:!0,adjustScaleRange:!0,borderWidth:2,borderDash:[],borderDashOffset:0,label:{backgroundColor:\"rgba(0,0,0,0.8)\",borderCapStyle:\"butt\",borderColor:\"black\",borderDash:",
		"[],borderDashOffset:0,borderJoinStyle:\"miter\",borderRadius:6,borderWidth:0,drawTime:void 0,font:{family:void 0,lineHeight:void 0,size:void 0,style:void 0,weight:\"bold\"},color:\"#fff\",xPadding:6,yPadding:6,rotation:0,position:\"center\",xAdjust:0,yAdjust:0,textAlign:\"center\",width:void 0,height:void 0,enabled:!1,content:null},value:void 0,endValue:void 0,scaleID:void 0,xScaleID:\"x\",xMin:void 0,xMax:void 0,yScaleID:\"y\",yMin:void 0,yMax:void 0},p.defaultRoutes={borderColor:\"color\"};const w=new Map;function M(e,t,n,o){const{xPadding:i,yPadding:r}=n,a=e.w*o.dx,s=e.h*o.dy,d=a>0&&(t.w/2+i-o.x)/a,c=s>0&&(t.h/2+r-o.y)/s;return l(Math.max(d,c),0,.25)}function v(e,t){const{size:n,min:o,max:i,padding:r}=t,a=n/2;return n>i-o?(i+o)/2:(o>=e-r-a&&(e=o+r+a),i<=e+r+a&&(e=i-r-a),e)}class D extends h{inRange(e,t){return function(e,t){const{width:n,height:o}=t,i=t.getCenterPoint(!0),r=n/2,a=o/2;if(r<=0||a<=0)return!1;return Math.pow(e.x-i.x,2)/Math.pow(r,2)+Math.pow(e.y-i.y,2)/Math.pow(a,2)<=1}",
		"({x:e,y:t},this)}draw(e){const{width:n,height:o,options:i}=this,r=this.getCenterPoint();e.save(),e.translate(r.x,r.y),i.rotation&&e.rotate(t.toRadians(i.rotation)),e.beginPath(),e.lineWidth=i.borderWidth,e.strokeStyle=i.borderColor,e.fillStyle=i.backgroundColor,e.setLineDash(i.borderDash),e.lineDashOffset=i.borderDashOffset,e.ellipse(0,0,o/2,n/2,Math.PI/2,0,2*Math.PI),e.fill(),e.stroke(),e.restore()}}D.id=\"ellipseAnnotation\",D.defaults={display:!0,adjustScaleRange:!0,borderDash:[],borderDashOffset:0,borderWidth:1,rotation:0,xScaleID:\"x\",xMin:void 0,xMax:void 0,yScaleID:\"y\",yMin:void 0,yMax:void 0},D.defaultRoutes={borderColor:\"color\",backgroundColor:\"color\"};class k extends e.Element{inRange(e,t){const{width:n,options:o}=this,i=this.getCenterPoint(!0),r=n/2+o.borderWidth;return!(r<=0)&&Math.pow(e-i.x,2)+Math.pow(t-i.y,2)<=Math.pow(r,2)}getCenterPoint(e){const{x:t,y:n}=this.getProps([\"x\",\"y\"],e);return{x:t,y:n}}draw(e){const{x:t,y:n,width:o,options:i}=this;e.save(),e.lineWi",
		"dth=i.borderWidth,e.strokeStyle=i.borderColor,e.fillStyle=i.backgroundColor,e.setLineDash(i.borderDash),e.lineDashOffset=i.borderDashOffset,e.beginPath(),e.arc(t,n,o/2,0,2*Math.PI),e.fill(),e.stroke(),e.restore()}resolveElementProperties(e,t){const{chartArea:n,scales:o}=e,i=o[t.xScaleID],r=o[t.yScaleID];let a=n.width/2,s=n.height/2;return i&&(a=c(i,t.xValue,a)),r&&(s=c(r,t.yValue,s)),{x:a,y:s,width:2*t.radius,height:2*t.radius}}}k.id=\"pointAnnotation\",k.defaults={display:!0,adjustScaleRange:!0,borderDash:[],borderDashOffset:0,borderWidth:1,radius:10,xScaleID:\"x\",xValue:void 0,yScaleID:\"y\",yValue:void 0},k.defaultRoutes={borderColor:\"color\",backgroundColor:\"color\"};const P=new Map,I={box:h,line:p,ellipse:D,point:k};Object.keys(I).forEach((t=>{e.defaults.describe(`elements.${I[t].id}`,{_fallback:\"plugins.annotation\"})}));var S={id:\"annotation\",version:\"1.1.0\",afterRegister(){e.Chart.register(I)},afterUnregister(){e.Chart.unregister(I)},beforeInit(e){P.set(e,{annotations:[]",
		",elements:[],listeners:{},listened:!1,moveListened:!1})},beforeUpdate(e,n,o){const i=P.get(e).annotations=[];let r=o.annotations;t.isObject(r)?Object.keys(r).forEach((e=>{const n=r[e];t.isObject(n)&&(n.id=e,i.push(n))})):t.isArray(r)&&i.push(...r)},afterDataLimits(e,n){const o=P.get(e);!function(e,n,o){const i=function(e,n){const o=e.axis,i=e.id,r=o+\"ScaleID\";let a=t.valueOrDefault(e.min,Number.NEGATIVE_INFINITY),s=t.valueOrDefault(e.max,Number.POSITIVE_INFINITY);for(const t of n)if(t.scaleID===i)for(const n of[\"value\",\"endValue\"]){const o=t[n];if(o){const t=e.parse(o);a=Math.min(a,t),s=Math.max(s,t)}}else if(t[r]===i)for(const n of[o+\"Min\",o+\"Max\",o+\"Value\"]){const o=t[n];if(o){const t=e.parse(o);a=Math.min(a,t),s=Math.max(s,t)}}return{min:a,max:s}}(n,o);let r=!1;t.isFinite(i.min)&&void 0===n.options.min&&void 0===n.options.suggestedMin&&(r=n.min!==i.min,n.min=i.min);t.isFinite(i.max)&&void 0===n.options.max&&void 0===n.options.suggestedMax&&(r=n.max!==i.max,n.max=i.max);r&",
		"&\"function\"==typeof n.handleTickRangeOptions&&n.handleTickRangeOptions()}(0,n.scale,o.annotations.filter((e=>e.display&&e.adjustScaleRange)))},afterUpdate(t,r,a){const s=P.get(t);!function(e,t,r){const a=t.annotations||[];t.listened=!1,t.moveListened=!1,i.forEach((e=>{\"function\"==typeof r[e]&&(t.listened=!0,t.listeners[e]=r[e])})),o.forEach((e=>{\"function\"==typeof r[e]&&(t.moveListened=!0)})),t.listened&&t.moveListened||a.forEach((e=>{t.listened||n.forEach((n=>{\"function\"==typeof e[n]&&(t.listened=!0)})),t.moveListened||o.forEach((n=>{\"function\"==typeof e[n]&&(t.listened=!0,t.moveListened=!0)}))}))}(0,s,a),function(t,n,o,i){const r=function(t,n,o){if(\"reset\"===o||\"none\"===o||\"resize\"===o)return C;return new e.Animations(t,n)}(t,o.animations,i),a=n.annotations,s=function(e,t){const n=t.length,o=e.length;if(o<n){const t=n-o;e.splice(o,0,...new Array(t))}else o>n&&e.splice(n,o-n);return e}(n.elements,a);for(let e=0;e<a.length;e++){const n=a[e];let o=s[e];const i=I[n.type]||",
		"I.line;o&&o instanceof i||(o=s[e]=new i);const l=O(n.setContext(T(t,o,n))),d=o.resolveElementProperties(t,l);d.skip=isNaN(d.x)||isNaN(d.y),d.options=l,r.update(o,d)}}(t,s,a,r.mode)},beforeDatasetsDraw(e){j(e,\"beforeDatasetsDraw\")},afterDatasetsDraw(e){j(e,\"afterDatasetsDraw\")},beforeDraw(e){j(e,\"beforeDraw\")},afterDraw(e){j(e,\"afterDraw\")},beforeEvent(e,t,n){r(e,P.get(e),t.event,n)},destroy(e){P.delete(e)},_getState:e=>P.get(e),defaults:{drawTime:\"afterDatasetsDraw\",dblClickSpeed:350,animations:{numbers:{properties:[\"x\",\"y\",\"x2\",\"y2\",\"width\",\"height\"],type:\"number\"}},label:{drawTime:null}},descriptors:{_indexable:!1,_scriptable:e=>!i.includes(e),annotations:{_allKeys:!1,_fallback:(e,t)=>`elements.${I[t.type||\"line\"].id}`}},additionalOptionScopes:[\"\"]};const C={update:Object.assign};function O(e){const t=I[e.type]||I.line,n={};n.id=e.id,n.type=e.type,n.drawTime=e.drawTime,Object.assign(n,R(e,t.defaults),R(e,t.defaultRoutes));for(const t of i)n[t]=e[t];return n",
		"}function R(e,n){const o={};for(const i of Object.keys(n)){const r=n[i],a=e[i];o[i]=t.isObject(r)?R(a,r):a}return o}function T(e,t,n){return t.$context||(t.$context=Object.assign(Object.create(e.getContext()),{element:t,id:n.id,type:\"annotation\"}))}function j(e,n){const{ctx:o,chartArea:i}=e,r=P.get(e).elements.filter((e=>!e.skip&&e.options.display));t.clipArea(o,i),r.forEach((e=>{e.options.drawTime===n&&e.draw(o)})),t.unclipArea(o),r.forEach((e=>{\"drawLabel\"in e&&e.options.label&&(e.options.label.drawTime||e.options.drawTime)===n&&e.drawLabel(o,i)}))}return e.Chart.register(S),S}));"
	};
	
	/**
	 * Creates the injectable resource with <code>chartjs-plugin-annotation.min.js</code> content.
	 */
	AnnotationPluginResource() {
		super(ResourceName.ANNOTATION_PLUGIN, CONTENT);
	}

}
