/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.intl.enums;

import org.pepstock.charba.client.commons.Key;

/**
 * Enumerates the numbering system to manage the number formatting.<br>
 * A numeral system is a system for expressing numbers.<br>
 * The numbering system property helps to represent the different numeral systems used by various countries, regions, and cultures around the world.
 * 
 * @author Andrea "Stock" Stocchero
 *
 */
public enum NumberingSystem implements Key
{
	/**
	 * International key, to use for localization, for <b>adlm</b> numbering system.
	 */
	ADLM("adlm"),

	/**
	 * International key, to use for localization, for <b>ahom</b> numbering system.
	 */
	AHOM("ahom"),

	/**
	 * International key, to use for localization, for <b>arab</b> numbering system.
	 */
	ARAB("arab"),

	/**
	 * International key, to use for localization, for <b>arabext</b> numbering system.
	 */
	ARABEXT("arabext"),

	/**
	 * International key, to use for localization, for <b>bali</b> numbering system.
	 */
	BALI("bali"),

	/**
	 * International key, to use for localization, for <b>beng</b> numbering system.
	 */
	BENG("beng"),

	/**
	 * International key, to use for localization, for <b>bhks</b> numbering system.
	 */
	BHKS("bhks"),

	/**
	 * International key, to use for localization, for <b>brah</b> numbering system.
	 */
	BRAH("brah"),

	/**
	 * International key, to use for localization, for <b>cakm</b> numbering system.
	 */
	CAKM("cakm"),

	/**
	 * International key, to use for localization, for <b>cham</b> numbering system.
	 */
	CHAM("cham"),

	/**
	 * International key, to use for localization, for <b>deva</b> numbering system.
	 */
	DEVA("deva"),

	/**
	 * International key, to use for localization, for <b>diak</b> numbering system.
	 */
	DIAK("diak"),

	/**
	 * International key, to use for localization, for <b>fullwide</b> numbering system.
	 */
	FULLWIDE("fullwide"),

	/**
	 * International key, to use for localization, for <b>gong</b> numbering system.
	 */
	GONG("gong"),

	/**
	 * International key, to use for localization, for <b>gonm</b> numbering system.
	 */
	GONM("gonm"),

	/**
	 * International key, to use for localization, for <b>gujr</b> numbering system.
	 */
	GUJR("gujr"),

	/**
	 * International key, to use for localization, for <b>guru</b> numbering system.
	 */
	GURU("guru"),

	/**
	 * International key, to use for localization, for <b>hanidec</b> numbering system.
	 */
	HANIDEC("hanidec"),

	/**
	 * International key, to use for localization, for <b>hmng</b> numbering system.
	 */
	HMNG("hmng"),

	/**
	 * International key, to use for localization, for <b>hmnp</b> numbering system.
	 */
	HMNP("hmnp"),

	/**
	 * International key, to use for localization, for <b>java</b> numbering system.
	 */
	JAVA("java"),

	/**
	 * International key, to use for localization, for <b>kali</b> numbering system.
	 */
	KALI("kali"),

	/**
	 * International key, to use for localization, for <b>khmr</b> numbering system.
	 */
	KHMR("khmr"),

	/**
	 * International key, to use for localization, for <b>knda</b> numbering system.
	 */
	KNDA("knda"),

	/**
	 * International key, to use for localization, for <b>lana</b> numbering system.
	 */
	LANA("lana"),

	/**
	 * International key, to use for localization, for <b>lanatham</b> numbering system.
	 */
	LANATHAM("lanatham"),

	/**
	 * International key, to use for localization, for <b>laoo</b> numbering system.
	 */
	LAOO("laoo"),

	/**
	 * International key, to use for localization, for <b>latn</b> numbering system.
	 */
	LATN("latn"),

	/**
	 * International key, to use for localization, for <b>lepc</b> numbering system.
	 */
	LEPC("lepc"),

	/**
	 * International key, to use for localization, for <b>limb</b> numbering system.
	 */
	LIMB("limb"),

	/**
	 * International key, to use for localization, for <b>mathbold</b> numbering system.
	 */
	MATHBOLD("mathbold"),

	/**
	 * International key, to use for localization, for <b>mathdbl</b> numbering system.
	 */
	MATHDBL("mathdbl"),

	/**
	 * International key, to use for localization, for <b>mathmono</b> numbering system.
	 */
	MATHMONO("mathmono"),

	/**
	 * International key, to use for localization, for <b>mathsanb</b> numbering system.
	 */
	MATHSANB("mathsanb"),

	/**
	 * International key, to use for localization, for <b>mathsans</b> numbering system.
	 */
	MATHSANS("mathsans"),

	/**
	 * International key, to use for localization, for <b>mlym</b> numbering system.
	 */
	MLYM("mlym"),

	/**
	 * International key, to use for localization, for <b>modi</b> numbering system.
	 */
	MODI("modi"),

	/**
	 * International key, to use for localization, for <b>mong</b> numbering system.
	 */
	MONG("mong"),

	/**
	 * International key, to use for localization, for <b>mroo</b> numbering system.
	 */
	MROO("mroo"),

	/**
	 * International key, to use for localization, for <b>mtei</b> numbering system.
	 */
	MTEI("mtei"),

	/**
	 * International key, to use for localization, for <b>mymr</b> numbering system.
	 */
	MYMR("mymr"),

	/**
	 * International key, to use for localization, for <b>mymrshan</b> numbering system.
	 */
	MYMRSHAN("mymrshan"),

	/**
	 * International key, to use for localization, for <b>mymrtlng</b> numbering system.
	 */
	MYMRTLNG("mymrtlng"),

	/**
	 * International key, to use for localization, for <b>newa</b> numbering system.
	 */
	NEWA("newa"),

	/**
	 * International key, to use for localization, for <b>nkoo</b> numbering system.
	 */
	NKOO("nkoo"),

	/**
	 * International key, to use for localization, for <b>olck</b> numbering system.
	 */
	OLCK("olck"),

	/**
	 * International key, to use for localization, for <b>orya</b> numbering system.
	 */
	ORYA("orya"),

	/**
	 * International key, to use for localization, for <b>osma</b> numbering system.
	 */
	OSMA("osma"),

	/**
	 * International key, to use for localization, for <b>rohg</b> numbering system.
	 */
	ROHG("rohg"),

	/**
	 * International key, to use for localization, for <b>saur</b> numbering system.
	 */
	SAUR("saur"),

	/**
	 * International key, to use for localization, for <b>segment</b> numbering system.
	 */
	SEGMENT("segment"),

	/**
	 * International key, to use for localization, for <b>shrd</b> numbering system.
	 */
	SHRD("shrd"),

	/**
	 * International key, to use for localization, for <b>sind</b> numbering system.
	 */
	SIND("sind"),

	/**
	 * International key, to use for localization, for <b>sinh</b> numbering system.
	 */
	SINH("sinh"),

	/**
	 * International key, to use for localization, for <b>sora</b> numbering system.
	 */
	SORA("sora"),

	/**
	 * International key, to use for localization, for <b>sund</b> numbering system.
	 */
	SUND("sund"),

	/**
	 * International key, to use for localization, for <b>takr</b> numbering system.
	 */
	TAKR("takr"),

	/**
	 * International key, to use for localization, for <b>talu</b> numbering system.
	 */
	TALU("talu"),

	/**
	 * International key, to use for localization, for <b>tamldec</b> numbering system.
	 */
	TAMLDEC("tamldec"),

	/**
	 * International key, to use for localization, for <b>telu</b> numbering system.
	 */
	TELU("telu"),

	/**
	 * International key, to use for localization, for <b>thai</b> numbering system.
	 */
	THAI("thai"),

	/**
	 * International key, to use for localization, for <b>tibt</b> numbering system.
	 */
	TIBT("tibt"),

	/**
	 * International key, to use for localization, for <b>tirh</b> numbering system.
	 */
	TIRH("tirh"),

	/**
	 * International key, to use for localization, for <b>vaii</b> numbering system.
	 */
	VAII("vaii"),

	/**
	 * International key, to use for localization, for <b>wara</b> numbering system.
	 */
	WARA("wara"),

	/**
	 * International key, to use for localization, for <b>wcho</b> numbering system.
	 */
	WCHO("wcho");

	// name value of property
	private final String value;

	/**
	 * Creates with the property value to use in the native object.
	 * 
	 * @param value value of property name
	 */
	private NumberingSystem(String value) {
		this.value = value;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.commons.Key#value()
	 */
	@Override
	public String value() {
		return value;
	}

}
